@@ -1,5 +1,10 @@
 """Representation of groups (scenes) from an ISY."""
-from ..constants import INSTEON_STATELESS_NODEDEFID, ISY_VALUE_UNKNOWN, PROTO_GROUP
+from ..constants import (
+    FAMILY_GENERIC,
+    INSTEON_BATTERY_NODEDEFID,
+    ISY_VALUE_UNKNOWN,
+    PROTO_GROUP,
+)
 from ..helpers import now
 from .nodebase import NodeBase
 
@@ -30,7 +35,7 @@ class Group(NodeBase):
         name,
         members=None,
         controllers=None,
-        family_id="6",
+        family_id=FAMILY_GENERIC,
         pnode=None,
     ):
         """Initialize a Group class."""
@@ -41,11 +46,12 @@ class Group(NodeBase):
 
         # listen for changes in children
         self._members_handlers = [
-            self._nodes[m].status_events.subscribe(self.update) for m in self.members
+            self._nodes[m].status_events.subscribe(self.update_callback)
+            for m in self.members
         ]
 
         # get and update the status
-        self.update()
+        self.isy.loop.create_task(self.update())
 
     def __del__(self):
         """Cleanup event handlers before deleting."""
@@ -60,7 +66,7 @@ class Group(NodeBase):
     @property
     def group_all_on(self):
         """Return the current node state."""
-        return self._status
+        return self._all_on
 
     @group_all_on.setter
     def group_all_on(self, value):
@@ -82,7 +88,7 @@ class Group(NodeBase):
         """Return the protocol for this entity."""
         return PROTO_GROUP
 
-    def update(self, event=None, wait_time=0, hint=None, xmldoc=None):
+    async def update(self, event=None, wait_time=0, xmldoc=None):
         """Update the group with values from the controller."""
         self._last_update = now()
         valid_nodes = [
@@ -91,14 +97,17 @@ class Group(NodeBase):
             if (
                 self._nodes[node].status is not None
                 and self._nodes[node].status != ISY_VALUE_UNKNOWN
-                and self._nodes[node].node_def_id not in INSTEON_STATELESS_NODEDEFID
+                and self._nodes[node].node_def_id not in INSTEON_BATTERY_NODEDEFID
             )
         ]
         on_nodes = [node for node in valid_nodes if int(self._nodes[node].status) > 0]
-
         if on_nodes:
             self.group_all_on = len(on_nodes) == len(valid_nodes)
             self.status = 255
             return
         self.status = 0
         self.group_all_on = False
+
+    def update_callback(self, event=None):
+        """Handle synchronous callbacks for subscriber events."""
+        self.isy.loop.create_task(self.update(event))
